summaryrefslogtreecommitdiff
path: root/include/global.h
diff options
context:
space:
mode:
Diffstat (limited to 'include/global.h')
-rw-r--r--include/global.h4
1 files changed, 2 insertions, 2 deletions
diff --git a/include/global.h b/include/global.h
index ead2e08..4531f77 100644
--- a/include/global.h
+++ b/include/global.h
@@ -180,9 +180,9 @@ private:
bool _exists;
/**
* The environment can access the private method from this class
*/
- friend class Environment;
+ friend class Globals;
};
/**
@@ -180,9 +180,9 @@ private:
bool _exists;
/**
- * The environment can access the private method from this class
+ * The globals can access the private method from this class
*/